@@ -11,8 +11,8 @@ our @ISA       = qw( Exporter ) ;
 our @EXPORT_OK = qw( new      ) ;
 our @Export    = qw( new      ) ;
 
-use vars qw( $VERSION )         ;
-$VERSION =                       '0.13' ;
+# use vars qw( $VERSION )         ;
+# $VERSION =                       '0.17' ;
 
 sub new        { shift and return bless { @_, 'timestamp'=>time }                    }
 
@@ -147,18 +147,10 @@ __END__
 
 Net::IRC2::Event - A parsed IRC message.
 
-=head1 VERSION
-
-!!! UNDER PROGRAMMING !!! Wait a moment, please hold the line ...
-
-Documentation in progress ...
-
 =head1 FUNCTIONS
 
 =over
 
-=item new()
-
 =item parent()
 
 return the Net::IRC2::Connection parent object
@@ -201,14 +193,22 @@ Should return the command in ALPHA if exist
 
 =item nick()
 
+Nickname of sender
+
 =item user()
 
+Username of sender
+
 =item host()
 
+Host of sender
+
 =item userhost()
 
 =item to()
 
+The message destination, could be a chan, you nick ...
+
 the Event's destination
 
 =back
@@ -217,6 +217,8 @@ the Event's destination
 
 =over
 
+=item new()
+
 =item convert()
 
 =back
